@@ -18,7 +18,7 @@
 #include "k3bdevicetypes.h"
 #include "k3bmsf.h"
 
-#include <KWidgetsAddons/KGuiItem>
+#include <KGuiItem>
 #include <QEvent>
 #include <QString>
 #include <QWaitCondition>
@@ -33,7 +33,7 @@ namespace K3b {
     class ThreadJobCommunicationEvent : public QEvent
     {
     public:
-        ~ThreadJobCommunicationEvent();
+        ~ThreadJobCommunicationEvent() override;
 
         enum Type {
             WaitForMedium = QEvent::User + 50,
