@@ -24,7 +24,7 @@
 #include "k3bglobals.h"
 #include "k3b_i18n.h"
 
-#include <KConfigCore/KConfig>
+#include <KConfig>
 
 #include <QDebug>
 #include <QRegExp>
