@@ -21,7 +21,7 @@
 
 #include "k3b_export.h"
 
-#include <KIOCore/KIO/Global>
+#include <KIO/Global>
 #include <QObject>
 #include <QString>
 #include <QUrl>
@@ -46,7 +46,7 @@ namespace K3b {
 
     public:
         explicit Doc( QObject* = 0 );
-        virtual ~Doc();
+        ~Doc() override;
 
         enum Type {
             AudioProject = 0x1,
@@ -73,7 +73,7 @@ namespace K3b {
         /**
          * The media types that are supported by this project type.
          * The default implementation returns all writable media types.
-         * This should NOT take into accout settings like the writing mode
+         * This should NOT take into account settings like the writing mode
          * or anything that can be changed in the burn dialog.
          */
         virtual Device::MediaTypes supportedMediaTypes() const;
