@@ -14,8 +14,8 @@
 
 #include "k3bimagefilereader.h"
 
-#include <QtCore/QDebug>
-#include <QtCore/QFile>
+#include <QDebug>
+#include <QFile>
 
 
 
