@@ -18,7 +18,7 @@
 
 #include "k3bvcddoc.h"
 
-#include <QtCore/QString>
+#include <QString>
 
 class QFile;
 
@@ -29,7 +29,7 @@ namespace K3b {
     {
 
     public:
-        VcdXmlView( VcdDoc* doc );
+        explicit VcdXmlView( VcdDoc* doc );
         ~VcdXmlView();
 
         void write( QFile& file );
