@@ -17,8 +17,8 @@
 #define _K3B_DEVICE_COMBO_BOX_H_
 
 #include "k3b_export.h"
-#include <KCompletion/KComboBox>
-#include <QtCore/QList>
+#include <KComboBox>
+#include <QList>
 
 namespace K3b {
     namespace Device {
@@ -36,8 +36,8 @@ namespace K3b {
         Q_OBJECT
 
     public:
-        DeviceComboBox( QWidget* parent = 0 );
-        ~DeviceComboBox();
+        explicit DeviceComboBox( QWidget* parent = 0 );
+        ~DeviceComboBox() override;
 
         Device::Device* selectedDevice() const;
 
