@@ -44,17 +44,17 @@ namespace K3b {
         /**
          * Destructs the validator.
          */
-        virtual ~IntValidator ();
+        ~IntValidator () override;
 
         /**
          * Validates the text, and return the result.  Does not modify the parameters.
          */
-        virtual State validate ( QString &, int & ) const;
+        State validate ( QString &, int & ) const override;
 
         /**
          * Fixes the text if possible, providing a valid string.  The parameter may be modified.
          */
-        virtual void fixup ( QString & ) const;
+        void fixup ( QString & ) const override;
 
         /**
          * Sets the minimum and maximum values allowed.
