@@ -15,8 +15,8 @@
 #ifndef _K3B_THREAD_WIDGET_H_
 #define _K3B_THREAD_WIDGET_H_
 
-#include <QtCore/QObject>
-#include <QtCore/QHash>
+#include <QObject>
+#include <QHash>
 
 namespace K3b {
     namespace Device {
@@ -35,7 +35,7 @@ namespace K3b {
         Q_OBJECT
 
     public:
-        ~ThreadWidget();
+        ~ThreadWidget() override;
 
         static ThreadWidget* instance();
 
@@ -49,7 +49,7 @@ namespace K3b {
         /**
          * communication between the threads
          */
-        void customEvent( QEvent* );
+        void customEvent( QEvent* ) override;
 
     private:
         /**
