@@ -18,7 +18,7 @@
 ** Foundation and appearing in the file LICENSE.LGPL included in the
 ** packaging of this file.  Please review the following information to
 ** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** will be met: https://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
 ** In addition, as a special exception, Nokia gives you certain
 ** additional rights. These rights are described in the Nokia Qt LGPL
@@ -31,7 +31,7 @@
 ** Foundation and appearing in the file LICENSE.GPL included in the
 ** packaging of this file.  Please review the following information to
 ** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** met: https://www.gnu.org/licenses/gpl-3.0.html.
 **
 ** If you are unsure which license is appropriate for your use, please
 ** contact the sales department at qt-sales@nokia.com.
@@ -41,7 +41,7 @@
 
 //#define QPROCESS_DEBUG
 #include "qdebug.h"
-
+#include <QElapsedTimer>
 #ifndef QT_NO_PROCESS
 
 #if defined QPROCESS_DEBUG
@@ -1002,7 +1002,7 @@ bool K3bQProcessPrivate::waitForReadyRead(int msecs)
     qDebug("K3bQProcessPrivate::waitForReadyRead(%d)", msecs);
 #endif
 
-    QTime stopWatch;
+    QElapsedTimer stopWatch;
     stopWatch.start();
 
     forever {
@@ -1078,7 +1078,7 @@ bool K3bQProcessPrivate::waitForBytesWritten(int msecs)
     if (processFlags&K3bQProcess::RawStdin)
         return true;
 
-    QTime stopWatch;
+    QElapsedTimer stopWatch;
     stopWatch.start();
 
     while (!writeBuffer.isEmpty()) {
@@ -1145,7 +1145,7 @@ bool K3bQProcessPrivate::waitForFinished(int msecs)
     qDebug("K3bQProcessPrivate::waitForFinished(%d)", msecs);
 #endif
 
-    QTime stopWatch;
+    QElapsedTimer stopWatch;
     stopWatch.start();
 
     forever {
