@@ -118,7 +118,7 @@ bool K3bLibsndfileDecoder::analyseFileInternal( K3b::Msf& frames, int& samplerat
             addTechnicalInfo( i18n("Channels"), QString::number(d->sndinfo.channels) );
             addTechnicalInfo( i18n("Sampling Rate"), i18n("%1 Hz",d->sndinfo.samplerate) );
 
-            frames = (unsigned long)ceil(d->sndinfo.frames / d->sndinfo.samplerate * 75.0);
+            frames = (unsigned long)ceil(75.0 * d->sndinfo.frames / d->sndinfo.samplerate);
             samplerate = d->sndinfo.samplerate;
             ch = d->sndinfo.channels;
 
@@ -161,10 +161,6 @@ int K3bLibsndfileDecoder::decodeInternal( char* data, int maxLen )
         qDebug() << "(K3bLibsndfileDecoder::decodeInternal) successfully finished decoding.";
         return 0;
     }
-    else if( read != maxLen ) {
-        qDebug() << "(K3bLibsndfileDecoder::decodeInternal) read:" << read << " expected:" << maxLen;
-        return -1;
-    }
     else
         return read;
 }
@@ -221,8 +217,7 @@ bool K3bLibsndfileDecoderFactory::canDecode( const QUrl& url )
         qDebug() << "(K3bLibsndfileDecoder) " << sf_strerror(sndfile);
         return false;
     }
-    //we exclude only WAVE as there is another plugin for this
-    else if ( infos.format && ((infos.format & SF_FORMAT_TYPEMASK) != SF_FORMAT_WAV) )  {
+    else if ( infos.format )  {
 
         //retrieve infos (name) about the format:
         SF_FORMAT_INFO format_info;
