@@ -27,13 +27,13 @@ class K3bMpcDecoderFactory : public K3b::AudioDecoderFactory
 
 public:
     K3bMpcDecoderFactory( QObject* parent, const QVariantList& );
-    ~K3bMpcDecoderFactory();
+    ~K3bMpcDecoderFactory() override;
 
-    bool canDecode( const QUrl& filename );
+    bool canDecode( const QUrl& filename ) override;
 
-    int pluginSystemVersion() const { return K3B_PLUGIN_SYSTEM_VERSION; }
+    int pluginSystemVersion() const override { return K3B_PLUGIN_SYSTEM_VERSION; }
 
-    K3b::AudioDecoder* createDecoder( QObject* parent = 0 ) const;
+    K3b::AudioDecoder* createDecoder( QObject* parent = 0 ) const override;
 };
 
 
@@ -43,16 +43,16 @@ class K3bMpcDecoder : public K3b::AudioDecoder
 
 public:
     explicit K3bMpcDecoder( QObject* parent = 0 );
-    ~K3bMpcDecoder();
+    ~K3bMpcDecoder() override;
 
-    QString fileType() const;
+    QString fileType() const override;
 
 protected:
-    bool analyseFileInternal( K3b::Msf& frames, int& samplerate, int& ch );
-    bool initDecoderInternal();
-    bool seekInternal( const K3b::Msf& );
+    bool analyseFileInternal( K3b::Msf& frames, int& samplerate, int& ch ) override;
+    bool initDecoderInternal() override;
+    bool seekInternal( const K3b::Msf& ) override;
 
-    int decodeInternal( char* _data, int maxLen );
+    int decodeInternal( char* _data, int maxLen ) override;
 
 private:
     K3bMpcWrapper* m_mpc;
