@@ -625,7 +625,7 @@ QStringList K3b::MetaItemModel::mimeTypes() const
     {
         types += it->model()->mimeTypes().toSet();
     }
-    return types.toList();
+    return types.values();
 }
 
 
@@ -840,7 +840,7 @@ void K3b::MetaItemModel::slotRowsAboutToBeInserted( const QModelIndex& parent, i
     else
         parentNode = place;
 
-    // if the node doesn't have children yet (maybe not yet acessed)
+    // if the node doesn't have children yet (maybe not yet accessed)
     // or if it has less items than the start point of this insertion
     // simply load the child nodes
     if (start > parentNode->children.count()) {
