@@ -106,7 +106,7 @@ K3b::MediaCopyDialog::MediaCopyDialog( QWidget *parent )
 
     QGroupBox* groupCopies = new QGroupBox( i18n("Copies"), optionTab );
     QLabel* pixLabel = new QLabel( groupCopies );
-    pixLabel->setPixmap( SmallIcon( "tools-media-optical-copy", KIconLoader::SizeMedium ) );
+    pixLabel->setPixmap( QIcon::fromTheme("tools-media-optical-copy").pixmap(KIconLoader::SizeMedium) );
     pixLabel->setScaledContents( false );
     m_spinCopies = new QSpinBox( groupCopies );
     m_spinCopies->setRange( 1, 999 );
@@ -475,7 +475,7 @@ void K3b::MediaCopyDialog::toggleAll()
         // selection of the writing mode
         //
         if( burnDev == readDev ) {
-            K3b::WritingModes modes = 0;
+            K3b::WritingModes modes = WritingModeAuto;
             if ( sourceMedium.diskInfo().mediaType() & K3b::Device::MEDIA_CD_ALL ) {
                 modes = K3b::WritingModeTao|K3b::WritingModeSao|K3b::WritingModeRaw;
             }
