@@ -28,7 +28,7 @@ namespace K3b {
 
     public:
         explicit VcdProjectModel( VcdDoc* doc, QObject* parent = 0 );
-        ~VcdProjectModel();
+        ~VcdProjectModel() override;
 
         enum Columns {
             NoColumn = 0,
@@ -49,18 +49,18 @@ namespace K3b {
         VcdTrack* trackForIndex( const QModelIndex& index ) const;
         QModelIndex indexForTrack( VcdTrack* track, int column = NoColumn ) const;
 
-        virtual int rowCount(const QModelIndex& parent = QModelIndex()) const;
-        virtual int columnCount(const QModelIndex& parent = QModelIndex()) const;
-        virtual QVariant data(const QModelIndex& index, int role = Qt::DisplayRole) const;
-        virtual bool setData( const QModelIndex& index, const QVariant& value, int role = Qt::EditRole );
-        virtual QVariant headerData(int section, Qt::Orientation orientation, int role) const;
-        virtual Qt::ItemFlags flags( const QModelIndex& index ) const;
-        virtual Qt::DropActions supportedDragActions() const;
-        virtual Qt::DropActions supportedDropActions() const;
-        virtual QMimeData* mimeData( const QModelIndexList& indexes ) const;
-        virtual QStringList mimeTypes() const;
-        virtual bool dropMimeData( const QMimeData* data, Qt::DropAction action, int row, int column, const QModelIndex& parent );
-        virtual bool removeRows( int row, int count, const QModelIndex& parent = QModelIndex() );
+        int rowCount(const QModelIndex& parent = QModelIndex()) const override;
+        int columnCount(const QModelIndex& parent = QModelIndex()) const override;
+        QVariant data(const QModelIndex& index, int role = Qt::DisplayRole) const override;
+        bool setData( const QModelIndex& index, const QVariant& value, int role = Qt::EditRole ) override;
+        QVariant headerData(int section, Qt::Orientation orientation, int role) const override;
+        Qt::ItemFlags flags( const QModelIndex& index ) const override;
+        Qt::DropActions supportedDragActions() const override;
+        Qt::DropActions supportedDropActions() const override;
+        QMimeData* mimeData( const QModelIndexList& indexes ) const override;
+        QStringList mimeTypes() const override;
+        bool dropMimeData( const QMimeData* data, Qt::DropAction action, int row, int column, const QModelIndex& parent ) override;
+        bool removeRows( int row, int count, const QModelIndex& parent = QModelIndex() ) override;
 
     private:
         class Private;
