@@ -19,7 +19,7 @@
 
 #include "k3bvideodvdtitletranscodingjob.h"
 
-#include <KIOCore/KIO/Global>
+#include <KIO/Global>
 
 class QTimer;
 
@@ -30,7 +30,7 @@ namespace K3b {
 
     public:
         explicit VideoDVDRippingWidget( QWidget* parent );
-        ~VideoDVDRippingWidget();
+        ~VideoDVDRippingWidget() override;
 
         VideoDVDTitleTranscodingJob::VideoCodec selectedVideoCodec() const;
         VideoDVDTitleTranscodingJob::AudioCodec selectedAudioCodec() const;
